aboutsummaryrefslogtreecommitdiffstats
path: root/include/jemalloc
diff options
context:
space:
mode:
authorJason Evans <jasone@canonware.com>2016-06-01 11:35:30 -0700
committerJason Evans <jasone@canonware.com>2016-06-05 20:42:23 -0700
commitc9a76481d8e411e52240a4e4313dbbfa99801073 (patch)
tree660f60cb2b699c808b43a302df061dc8ca29745d /include/jemalloc
parent127026ad989c06feda12371e584b4af4dffaf2db (diff)
downloadplatform_external_jemalloc_new-c9a76481d8e411e52240a4e4313dbbfa99801073.tar.gz
platform_external_jemalloc_new-c9a76481d8e411e52240a4e4313dbbfa99801073.tar.bz2
platform_external_jemalloc_new-c9a76481d8e411e52240a4e4313dbbfa99801073.zip
Rename chunks_{cached,retained,mtx} to extents_{cached,retained,mtx}.
Diffstat (limited to 'include/jemalloc')
-rw-r--r--include/jemalloc/internal/arena.h16
-rw-r--r--include/jemalloc/internal/witness.h2
2 files changed, 9 insertions, 9 deletions
diff --git a/include/jemalloc/internal/witness.h b/include/jemalloc/internal/witness.h
index 8c56c21a..e2f85634 100644
--- a/include/jemalloc/internal/witness.h
+++ b/include/jemalloc/internal/witness.h
@@ -24,7 +24,7 @@ typedef int witness_comp_t (const witness_t *, void *, const witness_t *,
#define WITNESS_RANK_PROF_GCTX 7U
#define WITNESS_RANK_ARENA 8U
-#define WITNESS_RANK_ARENA_CHUNKS 9U
+#define WITNESS_RANK_ARENA_EXTENTS 9U
#define WITNESS_RANK_ARENA_EXTENT_CACHE 10
#define WITNESS_RANK_RTREE_ELM 11U
diff --git a/include/jemalloc/internal/arena.h b/include/jemalloc/internal/arena.h
index f60b9d60..0707b863 100644
--- a/include/jemalloc/internal/arena.h
+++ b/include/jemalloc/internal/arena.h
@@ -235,20 +235,20 @@ struct arena_s {
malloc_mutex_t large_mtx;
/*
* Heaps of chunks that were previously allocated. These are used when
* allocating chunks, in an attempt to re-use address space.
*/
- extent_heap_t chunks_cached[NPSIZES];
- extent_heap_t chunks_retained[NPSIZES];
+ extent_heap_t extents_cached[NPSIZES];
+ extent_heap_t extents_retained[NPSIZES];
+ /* User-configurable extent hook functions. */
+ extent_hooks_t extent_hooks;
+ /* Protects extents_cached, extents_retained, and extent_hooks. */
+ malloc_mutex_t extents_mtx;
- malloc_mutex_t chunks_mtx;
/* Cache of extent structures that were allocated via base_alloc(). */
ql_head(extent_t) extent_cache;
malloc_mutex_t extent_cache_mtx;
- /* User-configurable extent hook functions. */
- extent_hooks_t extent_hooks;
-
/* bins is used to store heaps of free regions. */
arena_bin_t bins[NBINS];
};
@@ -235,20 +235,20 @@ struct arena_s {
malloc_mutex_t large_mtx;
/*
- * Heaps of chunks that were previously allocated. These are used when
- * allocating chunks, in an attempt to re-use address space.
+ * Heaps of extents that were previously allocated. These are used when
+ * allocating extents, in an attempt to re-use address space.
*/